@@ -1,9 +1,9 @@
-from bolinette import core
+from bolinette import blnt
 from bolinette.commands import command
 
 
 @command('init_db')
-async def init_db(context: 'core.BolinetteContext', *, run_seeders=True, **_):
+async def init_db(context: 'blnt.BolinetteContext', *, run_seeders=True, **_):
     await context.db.drop_all()
     await context.db.create_all()
     if run_seeders:
