@@ -77,6 +77,11 @@ def init_collection_models(context: blnt.BolinetteContext):
         context.add_model(model_name, model)
 
 
+@init_func
+async def init_databases(context: blnt.BolinetteContext):
+    await context.db.create_all()
+
+
 @init_func
 def init_repositories(context: blnt.BolinetteContext):
     for model_name, model in context.models:
